@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: http2
-version: 1.5.4
-id: http2-1.5.4-82dccce60697e4ed1d56153dae3e45f1
-key: http2_2xVpEXWRpwJID0FYFQeHrL
+version: 1.6.0
+id: http2-1.6.0-5a3c10b32b40700aa78aff4a30dc8790
+key: http2_LhvHuTBAvJmH3RlqrZ0NdL
 license: BSD3
 maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
 synopsis: HTTP/2.0 library including frames and HPACK
@@ -13,7 +13,8 @@ category: Network
 author: Kazu Yamamoto <kazu@iij.ad.jp>
 exposed: True
 exposed-modules:
-    Network.HPACK Network.HTTP2 Network.HTTP2.Priority
+    Network.HPACK Network.HPACK.Token Network.HTTP2
+    Network.HTTP2.Priority
 hidden-modules: Network.HPACK.Buffer Network.HPACK.Builder
                 Network.HPACK.Huffman Network.HPACK.Huffman.Bit
                 Network.HPACK.Huffman.ByteString Network.HPACK.Huffman.Decode
@@ -23,19 +24,19 @@ hidden-modules: Network.HPACK.Buffer Network.HPACK.Builder
                 Network.HPACK.HeaderBlock.Encode Network.HPACK.HeaderBlock.Integer
                 Network.HPACK.Table Network.HPACK.Table.Dynamic
                 Network.HPACK.Table.Entry Network.HPACK.Table.RevIndex
-                Network.HPACK.Table.Static Network.HPACK.Table.Token
-                Network.HPACK.Types Network.HTTP2.Decode Network.HTTP2.Encode
-                Network.HTTP2.Priority.PSQ Network.HTTP2.Priority.Queue
-                Network.HTTP2.Types
+                Network.HPACK.Table.Static Network.HPACK.Types Network.HTTP2.Decode
+                Network.HTTP2.Encode Network.HTTP2.Priority.PSQ
+                Network.HTTP2.Priority.Queue Network.HTTP2.Types
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/http2-1.5.4
-library-dirs: /usr/lib/ghc-7.10.3/site-local/http2-1.5.4
-data-dir: /usr/share/arm-linux-ghc-7.10.3/http2-1.5.4
-hs-libraries: HShttp2-1.5.4-2xVpEXWRpwJID0FYFQeHrL
+import-dirs: /usr/lib/ghc-7.10.3/site-local/http2-1.6.0
+library-dirs: /usr/lib/ghc-7.10.3/site-local/http2-1.6.0
+data-dir: /usr/share/arm-linux-ghc-7.10.3/http2-1.6.0
+hs-libraries: HShttp2-1.6.0-LhvHuTBAvJmH3RlqrZ0NdL
 depends:
     array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
+    case-insensitive-1.2.0.6-c6baeb35be7a5ef7e8151f5e00d87f59
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     psqueues-0.2.2.0-1c442d35f7d41befefb8cfb402624ddd
     stm-2.4.4.1-b43e402fc74ce6b0320fe4217e7e432d
